@@ -51,6 +51,14 @@ from .lazyyoutube import LazyyoutubeCommand
 from .funkwhalealbum import FunkwhalealbumCommand
 from .lazyfunkwhalealbum import LazyfunkwhalealbumCommand
 from .matchmaking import MatchmakingCommand
+from .cvstats import CvstatsCommand
+from .elevatormusic import ElevatormusicCommand
+from .royalpack import RoyalpackCommand
+from .givefiorygi import GivefiorygiCommand
+from .help import HelpCommand
+from .pug import PugCommand
+from .createtreasure import CreatetreasureCommand
+from .treasure import TreasureCommand
 
 # Enter the commands of your Pack here!
 available_commands = [
@@ -106,6 +114,14 @@ available_commands = [
     FunkwhalealbumCommand,
     LazyfunkwhalealbumCommand,
     MatchmakingCommand,
+    CvstatsCommand,
+    ElevatormusicCommand,
+    RoyalpackCommand,
+    GivefiorygiCommand,
+    HelpCommand,
+    PugCommand,
+    CreatetreasureCommand,
+    TreasureCommand,
 ]
 
 # Don't change this, it should automatically generate __all__
