@@ -1,8 +1,10 @@
-from .lazyplay import LazyplayCommand
-from royalnet.commands import *
+from typing import *
+import royalnet.commands as rc
 import aiohttp
 import urllib.parse
 
+from .lazyplay import LazyplayCommand
+
 
 class LazyfunkwhaleCommand(LazyplayCommand):
     name: str = "lazyfunkwhale"
@@ -23,5 +25,5 @@ class LazyfunkwhaleCommand(LazyplayCommand):
                                    f"/api/v1/search?query={search}") as response:
                 j = await response.json()
         if len(j["tracks"]) < 1:
-            raise UserError("Nessun file audio trovato con il nome richiesto.")
+            raise rc.UserError("Nessun file audio trovato con il nome richiesto.")
         return [f'{self.config["Funkwhale"]["instance_url"]}{j["tracks"][0]["listen_url"]}']
