@@ -1,10 +1,11 @@
 from typing import *
-from royalnet.commands import *
-from royalnet.utils import *
-from royalnet.backpack.tables import Alias
-from ..tables import Steam
 import steam
 import requests.exceptions
+import royalnet.commands as rc
+import royalnet.utils as ru
+import royalnet.backpack.tables as rbt
+
+from ..tables import Steam
 
 
 class SteamGame:
@@ -45,47 +46,47 @@ class SteamGame:
         return f"<{self.__class__.__qualname__} {self.appid} ({self.name})>"
 
 
-class SteammatchCommand(Command):
+class SteammatchCommand(rc.Command):
     name: str = "steammatch"
 
     description: str = "Vedi quali giochi hai in comune con uno o più membri!"
 
     syntax: str = "{royalnet_username}+"
 
-    def __init__(self, interface: CommandInterface):
+    def __init__(self, interface: rc.CommandInterface):
         super().__init__(interface)
         if "Steam" not in self.config or "web_api_key" not in self.config["Steam"]:
-            raise ConfigurationError("[c]Steam.web_api_key[/c] config option is missing!")
+            raise rc.ConfigurationError("[c]Steam.web_api_key[/c] config option is missing!")
         self._api = steam.WebAPI(self.config["Steam"]["web_api_key"])
 
-    async def run(self, args: CommandArgs, data: CommandData) -> None:
+    async def run(self, args: rc.CommandArgs, data: rc.CommandData) -> None:
         users = []
 
         author = await data.get_author(error_if_none=True)
         users.append(author)
 
         for arg in args:
-            user = await Alias.find_user(self.alchemy, data.session, arg)
+            user = await rbt.User.find(self.alchemy, data.session, arg)
             users.append(user)
 
         if len(users) < 2:
-            raise InvalidInputError("Devi specificare almeno un altro utente!")
+            raise rc.InvalidInputError("Devi specificare almeno un altro utente!")
 
         shared_games: Optional[set] = None
         for user in users:
             user_games = set()
             if len(user.steam) == 0:
-                raise UserError(f"{user} non ha un account Steam registrato!")
+                raise rc.UserError(f"{user} non ha un account Steam registrato!")
             for steam_account in user.steam:
                 steam_account: Steam
                 try:
-                    response = await asyncify(self._api.IPlayerService.GetOwnedGames,
-                                              steamid=steam_account._steamid,
-                                              include_appinfo=True,
-                                              include_played_free_games=True,
-                                              appids_filter=0)
+                    response = await ru.asyncify(self._api.IPlayerService.GetOwnedGames,
+                                                 steamid=steam_account._steamid,
+                                                 include_appinfo=True,
+                                                 include_played_free_games=True,
+                                                 appids_filter=0)
                 except requests.exceptions.HTTPError:
-                    raise ExternalError(f"L'account Steam di {user} è privato!")
+                    raise rc.ExternalError(f"L'account Steam di {user} è privato!")
                 games = response["response"]["games"]
                 for game in games:
                     user_games.add(SteamGame(**game))
@@ -94,7 +95,7 @@ class SteammatchCommand(Command):
             else:
                 shared_games = shared_games.intersection(user_games)
 
-        message_rows = [f"🎮 Giochi in comune tra {andformat([str(user) for user in users], final=' e ')}:"]
+        message_rows = [f"🎮 Giochi in comune tra {ru.andformat([str(user) for user in users], final=' e ')}:"]
         for game in sorted(list(shared_games), key=lambda g: g.name):
             message_rows.append(f"- {game}")
 
